#' Reporting tools for `shiny` modules.
#'
#' A collection of tools for creating, previewing and modifying reports from `shiny` modules.
#'
#' @keywords internal
"_PACKAGE"

#' @importFrom checkmate assert_string
#' @importFrom grid grid.newpage
#' @importFrom lifecycle badge
#' @importFrom R6 R6Class
#' @importFrom rmarkdown render
#' @importFrom yaml as.yaml
#' @importFrom lifecycle badge
NULL
